=======
Credits
=======

Development Lead
----------------

Ara Yeroyan <ar23yeroyan@gmail.com, ara_yeroyan@edu.aua.am>

Contributors
------------

Supervisor - Dr. Nikolay Karpov <karpnv@gmail.com, nkarpov@nvidia.com>
